<?php

/**
 * WordPress settings API demo class
 *
 * @author Tareq Hasan
 */
if ( !class_exists('WeDevs_Settings_API_Test' ) ):
class WeDevs_Settings_API_Test {

    private $settings_api;

    function __construct() {
        $this->settings_api = new WeDevs_Settings_API;

        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
    }

    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {
        add_options_page( 'Html5 Audio Player Settings', 'Html5 Audio Player Settings', 'delete_posts', 'html5ap_settings', array($this, 'plugin_page') );
    }

    function get_settings_sections() {
        $sections = array(
            array(
                'id' => 'wedevs_basics',
                'title' => __( 'Color Setting', 'wedevs' )
            ),
        );
        return $sections;
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields() {
        $settings_fields = array(
            'wedevs_basics' => array(
                array(
                    'name'    => 'color_one',
                    'label'   => __( 'Player Primary Color', 'wedevs' ),
                    'desc'    => __( 'Change the primary color of the player.', 'wedevs' ),
                    'type'    => 'color',
                    'default' => '#4f5b5f'
                ),
                array(
                    'name'    => 'color_two',
                    'label'   => __( 'Secondery Color ( Hover color )', 'wedevs' ),
                    'desc'    => __( 'Change the secondery color of the player.', 'wedevs' ),
                    'type'    => 'color',
                    'default' => '#1aafff'
                ),
                array(
                    'name'    => 'bg_color',
                    'label'   => __( 'Background Color', 'wedevs' ),
                    'desc'    => __( 'Change the background color of the player.', 'wedevs' ),
                    'type'    => 'color',
                    'default' => '#'
                ),				

            ),

        );

        return $settings_fields;
    }

    function plugin_page() {
        echo '<div class="wrap">';

        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();

        echo '</div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

}
endif;
new WeDevs_Settings_API_Test();